using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Windows.Input;
using Microsoft.Maui.Controls;

namespace RobobinApp
{
	public class MainPageViewModel : INotifyPropertyChanged
	{
		private bool _isBusy;
		private string _statusMessage;

		public ICommand ConnectToRobobinCommand { get; }

		public MainPageViewModel()
		{
			ConnectToRobobinCommand = new Command(async () => await OnConnectToRobobin());
		}

		public bool IsBusy
		{
			get => _isBusy;
			set
			{
				_isBusy = value;
				OnPropertyChanged();
			}
		}

		public string StatusMessage
		{
			get => _statusMessage;
			set
			{
				_statusMessage = value;
				OnPropertyChanged();
			}
		}

		private async Task OnConnectToRobobin()
		{
			try
			{
				IsBusy = true;
				StatusMessage = "Connecting to Robobin...";
				StatusMessage = "Connected to Robobin!";
				await Application.Current.MainPage.DisplayAlert("Connection", StatusMessage, "OK");
			}
			catch (Exception ex)
			{
				StatusMessage = $"Failed to connect: {ex.Message}";
				await Application.Current.MainPage.DisplayAlert("Error", StatusMessage, "OK");
			}
			finally
			{
				IsBusy = false;
			}
		}

		public event PropertyChangedEventHandler PropertyChanged;

		protected void OnPropertyChanged([CallerMemberName] string propertyName = null)
		{
			PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
		}
	}
}
